==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/Char/ToUpper.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define v175	((void*)startLabel+75)
#define v177	((void*)startLabel+84)
#define CT_v187	((void*)startLabel+236)
#define FN_LAMBDA173	((void*)startLabel+300)
#define CT_v191	((void*)startLabel+344)
#define CF_LAMBDA173	((void*)startLabel+352)
#define ST_v180	((void*)startLabel+372)
#define PP_LAMBDA173	((void*)startLabel+385)
#define PC_LAMBDA173	((void*)startLabel+385)
#define ST_v189	((void*)startLabel+385)
#define ST_v190	((void*)startLabel+407)
#define PS_v181	((void*)startLabel+460)
#define PS_v186	((void*)startLabel+472)
#define PS_v179	((void*)startLabel+484)
#define PS_v184	((void*)startLabel+496)
#define PS_v183	((void*)startLabel+508)
#define PS_v182	((void*)startLabel+520)
#define PS_v185	((void*)startLabel+532)
#define PS_v188	((void*)startLabel+544)
extern Node FN_Char_46isLower[];
extern Node FN_Prelude_46Enum_46Prelude_46Char_46fromEnum[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_45[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_43[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_Prelude_46error[];
extern Node PM_Char[];
extern Node PC_Char_46isLower[];
extern Node PC_Prelude_46error[];
extern Node PC_Prelude_46Num_46Prelude_46Int_46_43[];
extern Node PC_Prelude_46Num_46Prelude_46Int_46_45[];
extern Node PC_Prelude_46Enum_46Prelude_46Char_46fromEnum[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v187)
,};
Node FN_Char_46toUpper[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,53,0)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CHAR_P1,97,HEAP_CVAL_P1,9)
, bytes2word(HEAP_CVAL_N1,17,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,17,HEAP_OFF_N1)
, bytes2word(12,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CHAR_P1,65,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(10,HEAP_CVAL_N1,22,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,18)
,	/* v175: (byte 3) */
  bytes2word(HEAP_OFF_N1,12,RETURN_EVAL,PUSH_CVAL_P1)
, bytes2word(11,EVAL,NEEDHEAP_I32,JUMPFALSE)
,	/* v177: (byte 4) */
  bytes2word(4,0,PUSH_ARG_I1,RETURN_EVAL)
, bytes2word(HEAP_CVAL_P1,12,HEAP_CVAL_N1,27)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,13,HEAP_CVAL_N1,32)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v186)
, 0
, 0
, 0
, 0
, useLabel(PS_v185)
, 0
, 0
, 0
, 0
, useLabel(PS_v184)
, 0
, 0
, 0
, 0
, useLabel(PS_v183)
, 0
, 0
, 0
, 0
, useLabel(PS_v182)
, 0
, 0
, 0
, 0
, useLabel(PS_v181)
, 0
, 0
, 0
, 0
, 60001
, useLabel(ST_v180)
,	/* CT_v187: (byte 0) */
  HW(7,1)
, 0
,};
Node F0_Char_46toUpper[] = {
  CAPTAG(useLabel(FN_Char_46toUpper),1)
, useLabel(PS_v179)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Char_46isLower))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Char_46fromEnum))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_45))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_43))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA173))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v191)
,	/* FN_LAMBDA173: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v190)
, 60001
, useLabel(ST_v189)
,	/* CT_v191: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA173: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA173))
, useLabel(PS_v188)
, 0
, 0
, 0
,};
Node PP_Char_46toUpper[] = {
 };
Node PC_Char_46toUpper[] = {
 	/* ST_v180: (byte 0) */
  bytes2word(67,104,97,114)
, bytes2word(46,116,111,85)
, bytes2word(112,112,101,114)
,	/* PP_LAMBDA173: (byte 1) */
 	/* PC_LAMBDA173: (byte 1) */
 	/* ST_v189: (byte 1) */
  bytes2word(0,67,104,97)
, bytes2word(114,46,116,111)
, bytes2word(85,112,112,101)
, bytes2word(114,58,54,58)
, bytes2word(49,45,55,58)
,	/* ST_v190: (byte 3) */
  bytes2word(50,56,0,67)
, bytes2word(104,97,114,58)
, bytes2word(32,80,97,116)
, bytes2word(116,101,114,110)
, bytes2word(32,109,97,116)
, bytes2word(99,104,32,102)
, bytes2word(97,105,108,117)
, bytes2word(114,101,32,105)
, bytes2word(110,32,102,117)
, bytes2word(110,99,116,105)
, bytes2word(111,110,32,97)
, bytes2word(116,32,54,58)
, bytes2word(49,45,55,58)
, bytes2word(50,56,46,0)
,	/* PS_v181: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Char_46isLower)
,	/* PS_v186: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Prelude_46error)
,	/* PS_v179: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Char_46toUpper)
,	/* PS_v184: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Prelude_46Num_46Prelude_46Int_46_43)
,	/* PS_v183: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Prelude_46Num_46Prelude_46Int_46_45)
,	/* PS_v182: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Prelude_46Enum_46Prelude_46Char_46fromEnum)
,	/* PS_v185: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_LAMBDA173)
,	/* PS_v188: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_LAMBDA173)
, useLabel(PC_LAMBDA173)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/Char/ToUpper.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define v180	((void*)startLabel+75)
#define v182	((void*)startLabel+84)
#define CT_v192	((void*)startLabel+236)
#define FN_LAMBDA178	((void*)startLabel+300)
#define CT_v196	((void*)startLabel+344)
#define CF_LAMBDA178	((void*)startLabel+352)
#define ST_v185	((void*)startLabel+372)
#define PP_LAMBDA178	((void*)startLabel+385)
#define PC_LAMBDA178	((void*)startLabel+385)
#define ST_v194	((void*)startLabel+385)
#define ST_v195	((void*)startLabel+407)
#define PS_v186	((void*)startLabel+460)
#define PS_v191	((void*)startLabel+472)
#define PS_v184	((void*)startLabel+484)
#define PS_v189	((void*)startLabel+496)
#define PS_v188	((void*)startLabel+508)
#define PS_v187	((void*)startLabel+520)
#define PS_v190	((void*)startLabel+532)
#define PS_v193	((void*)startLabel+544)
extern Node FN_Char_46isLower[];
extern Node FN_Prelude_46Enum_46Prelude_46Char_46fromEnum[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_45[];
extern Node FN_Prelude_46Num_46Prelude_46Int_46_43[];
extern Node CF_Prelude_46otherwise[];
extern Node FN_NHC_46Internal_46_95patternMatchFail[];
extern Node PM_Char[];
extern Node PC_Char_46isLower[];
extern Node PC_NHC_46Internal_46_95patternMatchFail[];
extern Node PC_Prelude_46Num_46Prelude_46Int_46_43[];
extern Node PC_Prelude_46Num_46Prelude_46Int_46_45[];
extern Node PC_Prelude_46Enum_46Prelude_46Char_46fromEnum[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v192)
,};
Node FN_Char_46toUpper[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,EVAL)
, bytes2word(NEEDHEAP_I32,JUMPFALSE,53,0)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CHAR_P1,97,HEAP_CVAL_P1,9)
, bytes2word(HEAP_CVAL_N1,17,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,17,HEAP_OFF_N1)
, bytes2word(12,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CHAR_P1,65,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(10,HEAP_CVAL_N1,22,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,18)
,	/* v180: (byte 3) */
  bytes2word(HEAP_OFF_N1,12,RETURN_EVAL,PUSH_CVAL_P1)
, bytes2word(11,EVAL,NEEDHEAP_I32,JUMPFALSE)
,	/* v182: (byte 4) */
  bytes2word(4,0,PUSH_ARG_I1,RETURN_EVAL)
, bytes2word(HEAP_CVAL_P1,12,HEAP_CVAL_N1,27)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,13,HEAP_CVAL_N1,32)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v191)
, 0
, 0
, 0
, 0
, useLabel(PS_v190)
, 0
, 0
, 0
, 0
, useLabel(PS_v189)
, 0
, 0
, 0
, 0
, useLabel(PS_v188)
, 0
, 0
, 0
, 0
, useLabel(PS_v187)
, 0
, 0
, 0
, 0
, useLabel(PS_v186)
, 0
, 0
, 0
, 0
, 60001
, useLabel(ST_v185)
,	/* CT_v192: (byte 0) */
  HW(7,1)
, 0
,};
Node F0_Char_46toUpper[] = {
  CAPTAG(useLabel(FN_Char_46toUpper),1)
, useLabel(PS_v184)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Char_46isLower))
, VAPTAG(useLabel(FN_Prelude_46Enum_46Prelude_46Char_46fromEnum))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_45))
, VAPTAG(useLabel(FN_Prelude_46Num_46Prelude_46Int_46_43))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA178))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
, bytes2word(0,0,0,0)
, useLabel(CT_v196)
,	/* FN_LAMBDA178: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v195)
, 60001
, useLabel(ST_v194)
,	/* CT_v196: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA178: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA178))
, useLabel(PS_v193)
, 0
, 0
, 0
,};
Node PP_Char_46toUpper[] = {
 };
Node PC_Char_46toUpper[] = {
 	/* ST_v185: (byte 0) */
  bytes2word(67,104,97,114)
, bytes2word(46,116,111,85)
, bytes2word(112,112,101,114)
,	/* PP_LAMBDA178: (byte 1) */
 	/* PC_LAMBDA178: (byte 1) */
 	/* ST_v194: (byte 1) */
  bytes2word(0,67,104,97)
, bytes2word(114,46,116,111)
, bytes2word(85,112,112,101)
, bytes2word(114,58,54,58)
, bytes2word(49,45,55,58)
,	/* ST_v195: (byte 3) */
  bytes2word(50,56,0,67)
, bytes2word(104,97,114,58)
, bytes2word(32,80,97,116)
, bytes2word(116,101,114,110)
, bytes2word(32,109,97,116)
, bytes2word(99,104,32,102)
, bytes2word(97,105,108,117)
, bytes2word(114,101,32,105)
, bytes2word(110,32,102,117)
, bytes2word(110,99,116,105)
, bytes2word(111,110,32,97)
, bytes2word(116,32,54,58)
, bytes2word(49,45,55,58)
, bytes2word(50,56,46,0)
,	/* PS_v186: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Char_46isLower)
,	/* PS_v191: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_NHC_46Internal_46_95patternMatchFail)
,	/* PS_v184: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Char_46toUpper)
,	/* PS_v189: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Prelude_46Num_46Prelude_46Int_46_43)
,	/* PS_v188: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Prelude_46Num_46Prelude_46Int_46_45)
,	/* PS_v187: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_Prelude_46Enum_46Prelude_46Char_46fromEnum)
,	/* PS_v190: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_Char_46toUpper)
, useLabel(PC_LAMBDA178)
,	/* PS_v193: (byte 0) */
  useLabel(PM_Char)
, useLabel(PP_LAMBDA178)
, useLabel(PC_LAMBDA178)
,};
